@@ -10,14 +10,13 @@ from PIL import Image
 warnings.simplefilter('ignore', Image.DecompressionBombWarning)
 
 
-def start_job(dir_path, progressbar_batch, ocrmypdfsettings):
-	t = threading.Thread(target=batch_ocr, args=(dir_path, progressbar_batch, ocrmypdfsettings), daemon=True)
+def start_job(dir_path, currentfile, progressbar_batch, progressbar_singlefile, ocrmypdfsettings):
+	t = threading.Thread(target=batch_ocr, args=(dir_path, progressbar_batch, progressbar_singlefile, ocrmypdfsettings, currentfile), daemon=True)
 	t.start()
 
 def ocr_run(file_path, ocrmypdfsettings):
 	#runs ocrmypdf on given file
 	try:
-
 		ocr = ocrmypdf.ocr(file_path, file_path, **ocrmypdfsettings, plugins=["plugin_progressbar"])
 
 		print("OCR complete.\n")
@@ -39,7 +38,7 @@ def ocr_run(file_path, ocrmypdfsettings):
 		print(e)
 		return "Error"
 
-def batch_ocr(dir_path, progressbar_batch, ocrmypdfsettings):
+def batch_ocr(dir_path, progressbar_batch, progressbar_singlefile, ocrmypdfsettings, currentfile):
 	# walks through given path and uses OCR Function on every pdf in path
 	progressbar_batch.set(0.0)	#resets Progressbar
 	progress_precision = 0.0
@@ -50,6 +49,7 @@ def batch_ocr(dir_path, progressbar_batch, ocrmypdfsettings):
 		if file_ext == '.pdf':
 
 			print("Path:" + dir_path + "\n")
+			currentfile.set("Current File:" + dir_path )
 			ocr_run(dir_path, ocrmypdfsettings)
 			progressbar_batch.set(100)
 	elif(os.path.isdir(dir_path)==True):
@@ -60,7 +60,8 @@ def batch_ocr(dir_path, progressbar_batch, ocrmypdfsettings):
 				if file_ext == '.pdf':
 					number_of_files=number_of_files+1
 
-			percent = 100/number_of_files
+			if number_of_files >0:
+				percent = 100/number_of_files
 		for dir_name, subdirs, file_list in os.walk(dir_path):
 			print(file_list)
 
@@ -70,9 +71,11 @@ def batch_ocr(dir_path, progressbar_batch, ocrmypdfsettings):
 					full_path = dir_name + '/' + filename
 
 					print("Path:" + full_path + "\n")
+					currentfile.set("Current File:" + full_path )
 					ocr_run(full_path, ocrmypdfsettings)
 					progress_precision = progress_precision + percent
 					progressbar_batch.set(round(progress_precision))
+					progressbar_singlefile.set(0.0)
 
 	else:
 		print("Error")
